@@ -149,7 +149,7 @@ the preferences window.
             self.m_ui.display_error_message("%(message)s\n%(exception)s\n\n%(todo)s" % {
               'exception':e,
               'message': "<b>%s</b>" % _("Error loading python module:"),
-              'todo': _("Now you should configure sound from the preferences window."),
+              'todo': _("You should configure sound from the preferences window, and try to use an external midi player. Or try to recompile the program and check for error messages to see why the module is not built."),
               })
         elif e.errno == errno.EACCES:
             self.m_ui.display_error_message(
@@ -185,6 +185,9 @@ It is also possible that the OS sound setup is incorrect.
                 self.handle_href('%s.html' % self.m_teachers[self.m_running_exercise].m_P.header.help)
             else:
                 self.handle_href('%s.html' % self.m_ui.m_viewer)
+    def show_exercise_theory(self):
+        if self.m_teachers[self.m_running_exercise].m_P.header.theory:
+            self.m_ui.display_docfile("%s.html" % self.m_teachers[self.m_running_exercise].m_P.header.theory, "")
     def _practise_lesson_id(self, lesson_id, urlobj=None):
         """
         return the module name.
@@ -213,6 +216,9 @@ It is also possible that the OS sound setup is incorrect.
                 n.set_sensitive(False)
             return
         self.m_ui.box_dict[module].on_start_practise()
+        w = self.m_ui.g_ui_manager.get_widget("/Menubar/HelpMenu/PerExerciseHelp/HelpTheory")
+        if w:
+            w.set_sensitive(bool(self.m_teachers[module].m_P.header.theory))
         return module
     def test_lesson_id(self, lesson_id):
         self.m_test_mode = True
