@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome.ui
+import gtk
 import gobject
 import random
 
@@ -26,12 +26,12 @@ import abstract, const
 import lessonfile
 
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
     ERR_CONFIGURE = 2
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
+        abstract.Teacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.IdByNameLessonfile
         self.m_custom_mode = False
     def give_up(self):
@@ -118,7 +118,7 @@ class Gui(abstract.Gui):
         ##############
         # practise_box 
         ##############
-        self.practise_box.set_spacing(gnome.ui.PAD)
+        self.practise_box.set_spacing(gu.PAD)
         hbox = gu.bHBox(self.practise_box)
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.clear()
@@ -167,7 +167,7 @@ class Gui(abstract.Gui):
         self.g_intervalconfig_box = gu.bVBox(self.config_box, False)
         hbox = gu.bHBox(self.g_intervalconfig_box, False)
         hbox.pack_start(gtk.Label(_("First interval:")), False,
-                        padding=gnome.ui.PAD_SMALL)
+                        padding=gu.PAD_SMALL)
         self.g_rdbs = [pack_rdbs(hbox, self.update_first)]
         self.g_first_interval_up = IntervalCheckBox(self.m_exname,
                                                          'first_interval_up')
@@ -178,7 +178,7 @@ class Gui(abstract.Gui):
         #----------
         hbox = gu.bHBox(self.g_intervalconfig_box, False)
         hbox.pack_start(gtk.Label(_("Last interval:")), False,
-                        padding=gnome.ui.PAD_SMALL)
+                        padding=gu.PAD_SMALL)
         self.g_rdbs.append (pack_rdbs(hbox, self.update_last))
         self.g_last_interval_up = IntervalCheckBox(self.m_exname,
                      'last_interval_up')
