@@ -20,7 +20,7 @@ from __future__ import division
 import os
 import pickle
 import time
-import gtk, gnome, gobject
+import gtk, gobject
 import gu, inputwidgets
 from multipleintervalconfigwidget import IntervalCheckBox
 import soundcard, mpd
@@ -32,23 +32,20 @@ import random
 import gethomedir
 import lessonfile
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     OK = 0
     ERR_PICKY = 1
     ERR_NO_INTERVALLS = 2
     ERR_NOTERANGE = 3
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        abstract.Teacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.IntervalsLessonfile
         self.m_statistics = statistics.HarmonicIntervalStatistics(self)
         self.m_tonika = None
         self.m_interval = None
     def enter_test_mode(self):
         self.m_statistics.enter_test_mode()
-        count, t = lessonfile.parse_test_def(self.m_P.header.test)
-        self.m_test_questions = self.get_list('intervals') * count
-        random.shuffle(self.m_test_questions)
-        self.m_test_idx = -1
+        self.m_P.enter_test_mode()
     def new_question(self, L, H):
         """
         Return values:
@@ -61,8 +58,8 @@ class Teacher(abstract.LessonbasedTeacher):
             self.m_timeout_handle = None
 
         if self.m_app.m_test_mode:
-            self.m_test_idx += 1
-            self.m_interval = self.m_test_questions[self.m_test_idx]
+            self.m_P.next_test_question()
+            self.m_interval = self.m_P.m_test_questions[self.m_P.m_test_idx]
             #FIXME use tone pitch range from preferences window.
             self.m_tonika = mpd.MusicalPitch()
             self.m_tonika.randomize("f", "f'")
@@ -189,11 +186,11 @@ class Gui(abstract.IntervalGui):
                 self.on_end_practise()
                 self.on_start_practise()
         self.add_watch('intervals', _ff)
-        self.g_interval_selector.set_border_width(gnome.ui.PAD)
+        self.g_interval_selector.set_border_width(gu.PAD)
         frame.add(self.g_interval_selector)
         #------we need some space
         self.config_box.pack_start(gtk.HBox(), False,
-                                   padding=gnome.ui.PAD_SMALL)
+                                   padding=gu.PAD_SMALL)
         # ------------------------------------------
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------------------
@@ -275,7 +272,7 @@ class Gui(abstract.IntervalGui):
         button, or when you use the key bindings. So it can be called even
         if the 'New interval' button is insensitive.
         """
-        if self.m_t.m_app.m_test_mode and self.m_t.is_test_complete():
+        if self.m_t.m_app.m_test_mode and self.m_t.m_P.is_test_complete():
             self.do_test_complete()
             return
         if self.m_t.m_app.m_test_mode:
@@ -323,6 +320,7 @@ class Gui(abstract.IntervalGui):
         else:
             self.m_t.m_statistics.reset_session()
             self.g_ask_for_frame.hide()
+        self.g_statview.g_heading.set_text("%s - %s" % (_("Harmonic interval"), self.m_t.m_P.header.title))
         self.g_new_interval.grab_focus()
         if self.m_t.m_app.m_test_mode:
             gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
