@@ -116,6 +116,11 @@ class Gui(abstract.LessonbasedGui):
               _("_Give up"), self.give_up)
         self.g_give_up.set_sensitive(False)
 
+        # This button exist mostly for historical reasons, but I think
+        # it an be usedful, even thoug it is not much used today (as in
+        # Solfege 3.6). It will present a Show button for exercises that
+        # does not have a music displayer. And the button will be insensitive
+        # until the question has been solved.
         self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_answer)
         self.g_show.set_sensitive(False)
         self.practise_box.show_all()
@@ -325,8 +330,8 @@ class Gui(abstract.LessonbasedGui):
         for question in self.m_t.m_P.m_questions:
             question['active'] = 1
         self.setup_action_area_buttons()
-        self.update_select_question_buttons()
         self.update_answer_buttons()
+        self.update_select_question_buttons()
         self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
         self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
         self.g_flashbar.require_size([
@@ -342,6 +347,12 @@ class Gui(abstract.LessonbasedGui):
             self.m_t.m_statistics.reset_session()
         self.g_statview.g_heading.set_text(self.m_t.m_P.header.title)
         self.g_music_displayer.clear()
+        # We only want the Show button if there are any questions that can
+        # be displayed.
+        if [q for q in self.m_t.m_P.m_questions if q['music'].is_displayable()] and not self.m_t.m_P.header.have_music_displayer:
+            self.g_show.show()
+        else:
+            self.g_show.hide()
         if self.m_t.m_app.m_test_mode:
             gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
                 self.g_flashbar.flash(_("Click 'Start test' to begin.")))
