@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
+import inputwidgets, abstract, const, random, soundcard, gu, mpd
 import gobject
 import runtime
 import gtk
@@ -23,15 +23,15 @@ import gu
 import statistics, statisticsviewer
 import lessonfile
 
-class Teacher(abstract.LessonbasedTeacher):
+class Teacher(abstract.Teacher):
     #FIXME the following lines
     OK, ERR_PICKY, ERR_TONES = range(3)
     ERR_PICKY = 1
     ERR_CONFIG = 2
     OCTAVES = [-2, -1, 0, 1, 2, 3]
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app)
-        self.lessonfileclass = lessonfile.IdByNameLessonfile
+        abstract.Teacher.__init__(self, exname, app)
+        self.lessonfileclass = lessonfile.HeaderLessonfile
         self.m_statistics = statistics.LessonStatistics(self)
         self.m_ask_tones =   {}
         self.m_question = None
@@ -105,12 +105,12 @@ class Teacher(abstract.LessonbasedTeacher):
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
-        if runtime.has_gnome_canvas() or runtime.use_cairo_widgets:
+        if runtime.use_cairo_widgets:
             self.m_usable = True
         else:
             self.m_usable = False
         if not self.m_usable:
-            label = gtk.Label(_("This exercise is disabled because some required features are missing from your computer. You should either install PyGTK 2.8.0 or newer, or GnomeCanvas and its python bindings."))
+            label = gtk.Label(_("This exercise is disabled because some required features are missing from your computer. You should install PyGTK 2.8.0 or newer."))
             label.set_line_wrap(True)
             self.practise_box.add(label)
             self.practise_box.show_all()
@@ -131,7 +131,7 @@ class Gui(abstract.Gui):
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
         self.practise_box.pack_start(self.g_flashbar, False)
-        self.practise_box.set_spacing(gnome.ui.PAD)
+        self.practise_box.set_spacing(gu.PAD)
 
         self.g_new_tone = gu.bButton(self.action_area, _("_New tone"),
                                      self.new_question)
@@ -144,12 +144,12 @@ class Gui(abstract.Gui):
         ##############
         # config_box #
         ##############
-        self.config_box.set_spacing(gnome.ui.PAD_SMALL)
+        self.config_box.set_spacing(gu.PAD_SMALL)
         # bad variable name, but this is the config options that should
         # not change without chaning lesson_id
         self.g_config_elems = gu.bVBox(self.config_box)
         table = gtk.Table()
-        table.set_border_width(gnome.ui.PAD_SMALL)
+        table.set_border_width(gu.PAD_SMALL)
         frame = gtk.Frame(_("Weight"))
         self.g_config_elems.pack_start(frame, False)
         frame.add(table)
@@ -183,7 +183,7 @@ class Gui(abstract.Gui):
         #############
         frame = gtk.Frame(_("When you guess wrong"))
         vbox = gtk.VBox()
-        vbox.set_border_width(gnome.ui.PAD_SMALL)
+        vbox.set_border_width(gu.PAD_SMALL)
         frame.add(vbox)
         vbox.pack_start(gu.nCheckButton(self.m_exname,
                     "warning_sound", _("Play warning sound")))
@@ -263,8 +263,6 @@ _("""You have to select some tones practise. Do this on the config page by setti
             _("Correct, but you have already solved this question"),
             _("Wrong, but you have already solved this question"),
         ])
-        if not self.m_usable:
-            return # this exercise don't work without GnomeCanvas
         if 'white_keys_weight' in self.m_t.m_P.header:
             if type(self.m_t.m_P.header.white_keys_weight) == list \
                     and len(self.m_t.m_P.header.white_keys_weight) == 7:
@@ -284,6 +282,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
         else:
             self.g_config_elems.hide()
             self.m_t.m_statistics.reset_session()
+        self.g_statview.g_heading.set_text("%s - %s" % (_("Identify tone"), self.m_t.m_P.header.title))
         self.set_percentage_label()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New tone' to begin.")))
