@@ -778,6 +778,9 @@ class Window(gtk.Window):
             create_for_children(menu, None)
         self.g_treeview.set_model(self.m_model)
     def on_new(self, widget):
+        if self.m_tree.m_modified:
+            if gu.dialog_yesno(_("The file is not saved. Save before changing?"), self):
+                self._do_save(self.m_filename)
         dlg = gtk.Dialog(_("Create new learning tree"), self, buttons=
             (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
             gtk.STOCK_OK, gtk.RESPONSE_OK))
@@ -812,6 +815,8 @@ class Window(gtk.Window):
                     self.g_filename_description.show()
                 else:
                     try:
+                        if not os.path.exists(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees')):
+                            os.makedirs(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees'))
                         f = file(os.path.join(gethomedir.get_home_dir(), '.solfege', 'learningtrees', filename), 'w')
                         f.write("""
 [ # toplevel list
