@@ -642,12 +642,12 @@ class QuestionsLessonfile(LessonfileCommon):
         assert len(instrument) in (2, 6)
         if len(instrument) == 2:
             m = self.get_music_as_notename_string(varname)
-            mpd.play_music(r"\staff{%s}" % m, self.get_tempo(),
+            mpd.play_music(r"\staff{%s}" % m, cfg.get_int('config/arpeggio_bpm'),
                        instrument[0], instrument[1])
         else:
             assert len(instrument) == 6
             track = soundcard.Track()
-            track.set_bpm(cfg.get_int('config/default_bpm'))#FIXME skulle dette vart tatt fra lesson file?
+            track.set_bpm(cfg.get_int('config/arpeggio_bpm'))
             nlist = self.get_music_as_notename_list(varname)
             # set patches
             track.set_patch(0, instrument[0])
