@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import gtk, gnome, gu
+import gtk, gu
 import const
 import cfg
 
@@ -67,7 +67,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         self._watched_interval = None
         self.m_ignore_iclick = 0
         box = gu.bHBox(self, expand=False)
-        box.set_spacing(gnome.ui.PAD_SMALL)
+        box.set_spacing(gu.PAD_SMALL)
         box.pack_start(gtk.Label(_("Number of intervals:")), False)
         self.g_num_int_spin = gu.nSpinButton(self.m_exname,
                        'number_of_intervals',
@@ -81,7 +81,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
                self.g_all_int_button.set_sensitive(self.get_int(n)!=1))
 
         box = gu.bHBox(self, expand=False)
-        box.set_spacing(gnome.ui.PAD_SMALL)
+        box.set_spacing(gu.PAD_SMALL)
         box.pack_start(gtk.Label(
                 _("Togglebuttons are for interval number:")), False)
         self.m_int_sel_adjustment \
@@ -95,7 +95,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
 
         label = gtk.Label(_("Up:"))
         label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 0, 1, xpadding=gnome.ui.PAD_SMALL)
+        table.attach(label, 0, 1, 0, 1, xpadding=gu.PAD_SMALL)
         self.g_interval_chk = {}
         V = self.get_list("ask_for_intervals_%i"
                   % (self.g_int_sel_spin.get_value_as_int()-1))
@@ -111,7 +111,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         box = gu.bHBox(self, expand=False)
         label = gtk.Label(_("Down:"))
         label.set_alignment(1.0, 0.5)
-        table.attach(label, 0, 1, 1, 2, xpadding=gnome.ui.PAD_SMALL)
+        table.attach(label, 0, 1, 1, 2, xpadding=gu.PAD_SMALL)
         v = range(-16, 0)
         v.reverse()
         for x in v:
