@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import gtk, gu
-import gnome
 import os
 
 
@@ -24,7 +23,7 @@ class MatrixTable(gtk.VBox):
     def __init__(self, label_style, heading, keys, key_to_pretty_name, dict):
         gtk.VBox.__init__(self)
         label = gtk.Label(heading)
-        label.set_name("Heading2")
+        label.set_name("StatisticsH2")
         label.set_alignment(0.0, 0.0)
         self.pack_start(label, False)
         hbox = gu.bHBox(self, False)
@@ -43,7 +42,7 @@ class MatrixTable(gtk.VBox):
             else:
                 l = gtk.Label(key_to_pretty_name(keys[y]))
                 l.set_alignment(0.0, 0.5)
-            t.attach(l, 0, 1, y*2, y*2+1, xpadding=gnome.ui.PAD)
+            t.attach(l, 0, 1, y*2, y*2+1, xpadding=gu.PAD)
             for x in range(len(keys)):
                 if keys[x] in dict and keys[y] in dict[keys[x]]:
                     s = str(dict[keys[x]][keys[y]])
@@ -51,8 +50,8 @@ class MatrixTable(gtk.VBox):
                     s = "0"
                 l = gtk.Label(s)
                 if x == y:
-                    l.set_name('StatisticsViewerDiagonal')
-                t.attach(l, x*2+2, x*2+3, y*2, y*2+1, xpadding=gnome.ui.PAD)
+                    l.set_name('BoldText')
+                t.attach(l, x*2+2, x*2+3, y*2, y*2+1, xpadding=gu.PAD)
         self.show_all()
 
 
@@ -84,7 +83,7 @@ class PercentagesTable(gtk.Frame):
         self.boxdict['keys'] = key_box = gtk.VBox()
         table.attach(key_box, 0, 1, 4, 5)
         for box in self.boxdict.values():
-            box.set_border_width(gnome.ui.PAD_SMALL)
+            box.set_border_width(gu.PAD_SMALL)
         self.update(statistics)
         self.show_all()
     def update(self, statistics):
@@ -96,8 +95,7 @@ class PercentagesTable(gtk.Frame):
             if k is None:
                 print "WARNING: statistics: key==None. Please, please report to"
                 print "bug-solfege@gnu.org if you get this message. Preferably,"
-                print "make a copy ~/.solfege and ~/.gnome/solfegeX.Y so I can"
-                print "debug this."
+                print "make a copy ~/.solfege so I can debug this."
             if statistics.get_label_style() == 'progression':
                 l = gu.HarmonicProgressionLabel(statistics.key_to_pretty_name(k), 'left')
             else:
@@ -123,20 +121,23 @@ class NewAbstractStatisticsViewer(gtk.ScrolledWindow):
         gtk.ScrolledWindow.__init__(self)
         self.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.vbox = gtk.VBox()
-        self.vbox.set_spacing(gnome.ui.PAD)
-        self.vbox.set_border_width(gnome.ui.PAD)
+        self.vbox.set_spacing(gu.PAD)
+        self.vbox.set_border_width(gu.PAD)
         self.add_with_viewport(self.vbox)
-        label = gtk.Label(heading)
-        label.set_alignment(0.0, 0.5)
-        label.set_name("Heading1")
-        self.vbox.pack_start(label, False)
+        self.g_heading = gtk.Label(heading)
+        self.g_heading.set_alignment(0.0, 0.5)
+        self.g_heading.set_name("StatisticsH1")
+        self.vbox.pack_start(self.g_heading, False)
         self.m_statistics = statistics
         self.g_tables = gtk.VBox()
         self.g_tables.show()
         self.vbox.pack_start(self.g_tables)
         self.show_all()
 
-class SingIntervalStatisticsViewer(NewAbstractStatisticsViewer):
+class PercentagesStatisticsViewer(NewAbstractStatisticsViewer):
+    """
+    A statistics viewer that will only display the Percentages table.
+    """
     def __init__(self, statistics, heading):
         NewAbstractStatisticsViewer.__init__(self, statistics, heading)
         #self.clear = self.g_p.clear
